# WriteRequestWrites


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**tuple_keys** | [**list[TupleKey]**](TupleKey.md) |  | 
**on_duplicate** | **str** | On &#39;error&#39; ( or unspecified ), the API returns an error if an identical tuple already exists. On &#39;ignore&#39;, identical writes are treated as no-ops (matching on user, relation, object, and RelationshipCondition). | [optional] [default to 'error']

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


